@@ -1,4 +1,4 @@
-`Met.RadioBox1` <-
+Met.RadioBox1 <-
 function(title,question1,question2, question4, answer1,answer2, answer4)
 {
   Require("tcltk")
