@@ -195,8 +195,6 @@ command=function() Met.Selection(datos,externa))
     command=function() Met.Binning(datos))
   tkadd(Pretratamiento,"command",label="Normalization",
     command=function() Met.Norm(datos))
-  tkadd(Pretratamiento,"command",label="Baseline",
-    command=function() Met.Baseline(datos))
   tkadd(Pretratamiento,"command",label="Baseline (FTICRMS)",
     command=function() Baseline.Correction())
   tkadd(Pretratamiento,"command",label="Metabolites order by discriminantion quality",
